#
# spec file for package kubectl-operator
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kubectl-operator
Version:        0.6.0
Release:        1.1
Summary:        Manage Kubernetes Operators from the command line
License:        Apache-2.0
URL:            https://github.com/operator-framework/kubectl-operator
Source:         kubectl-operator-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

%description
kubectl operator is a kubectl plugin that functions as a package manager for
Operators in your cluster. It simplifies adding and removing Operator catalogs,
and it has familiar commands for installing, uninstalling, and listing
available and installed Operators.

NOTE: This plugin requires Operator Lifecycle Manager to be installed in your cluster. See the OLM installation instructions here:
https://olm.operatorframework.io/docs/getting-started/

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-s -w \
   -X github.com/operator-framework/kubectl-operator/internal/version.GitVersion=%{version} \
   -X github.com/operator-framework/kubectl-operator/internal/version.GitCommit=v%{version} \
   -X github.com/operator-framework/kubectl-operator/internal/version.GitTreeState=clean" \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Fri Jan 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.6.0:
  * :seedling: bump to go1.23.0 (#203)
  * fix bingo-upgrade target (#215)
  * Bump rajatjindal/krew-release-bot from 0.0.46 to 0.0.47 (#214)
  * Bump k8s.io/apiextensions-apiserver from 0.31.0 to 0.31.1
    (#209)
  * Bump github.com/containerd/containerd from 1.7.21 to 1.7.22
    (#207)
  * Bump github.com/operator-framework/operator-registry (#206)
  * Bump github.com/operator-framework/operator-controller (#205)
  * Bump github.com/operator-framework/operator-controller from
    0.13.0 to 0.14.0 (#204)
  * :seedling: update bingo + tools (#202)
  * Bump github.com/operator-framework/operator-controller (#198)
  * Bump github.com/operator-framework/operator-registry (#196)
  * bump to go1.22.5 (#201)
  * Bump github.com/containerd/containerd from 1.7.20 to 1.7.21
    (#199)
  * Bump github.com/onsi/gomega from 1.34.1 to 1.34.2 (#200)
  * Bump github.com/operator-framework/api from 0.26.0 to 0.27.0
    (#197)
  * Bump k8s.io/client-go from 0.30.3 to 0.31.0 (#194)
  * Bump k8s.io/apimachinery from 0.30.3 to 0.31.0 (#193)
  * Bump sigs.k8s.io/controller-runtime from 0.18.4 to 0.18.5
    (#192)
  * Bump github.com/onsi/gomega from 1.34.0 to 1.34.1 (#191)
  * Bump github.com/onsi/gomega from 1.33.1 to 1.34.0 (#190)
  * Bump github.com/containerd/containerd from 1.7.19 to 1.7.20
    (#189)
  * Bump k8s.io/apiextensions-apiserver from 0.30.2 to 0.30.3
    (#186)
  * Bump github.com/operator-framework/operator-registry (#188)
  * Bump k8s.io/client-go from 0.30.2 to 0.30.3 (#187)
  * Bump github.com/operator-framework/operator-controller (#183)
  * Bump github.com/operator-framework/operator-controller (#179)
    (#182)
  * Bump github.com/operator-framework/operator-controller (#179)
  * Bump github.com/operator-framework/operator-registry (#180)
  * Bump actions/add-to-project from 1.0.1 to 1.0.2 (#178)
  * Bump github.com/spf13/cobra from 1.8.0 to 1.8.1 (#176)
  * Bump k8s.io/apiextensions-apiserver from 0.30.1 to 0.30.2
    (#172)
  * Bump k8s.io/client-go from 0.30.1 to 0.30.2 (#174)
  * Bump github.com/operator-framework/api from 0.25.0 to 0.26.0
    (#175)
  * Bump sigs.k8s.io/controller-runtime from 0.18.3 to 0.18.4
    (#170)
  * Bump github.com/containerd/containerd from 1.7.17 to 1.7.18
    (#169)
  * Bump github.com/operator-framework/operator-registry (#167)
  * Bump sigs.k8s.io/controller-runtime from 0.18.2 to 0.18.3
    (#168)
  * Bump github.com/operator-framework/api from 0.24.0 to 0.25.0
    (#166)
  * Bump github.com/operator-framework/operator-registry (#165)
  * Bump github.com/containerd/containerd from 1.7.16 to 1.7.17
    (#164)
  * Bump k8s.io/apiextensions-apiserver from 0.30.0 to 0.30.1
    (#163)
  * Bump k8s.io/client-go from 0.30.0 to 0.30.1 (#160)
  * Bump github.com/operator-framework/operator-controller (#157)
  * Bump github.com/operator-framework/operator-registry (#162)
  * Bump k8s.io/apimachinery from 0.30.0 to 0.30.1 (#158)
  * Bump k8s.io/api from 0.30.0 to 0.30.1 (#161)
  * Bump github.com/operator-framework/api from 0.23.0 to 0.24.0
    (#153)
  * Bump sigs.k8s.io/controller-runtime from 0.18.0 to 0.18.2
    (#155)
  * Bump github.com/operator-framework/operator-registry (#149)
  * bump k8s apis to 1.30 and controller-runtime to 0.18.0 (#146)
* Tue Apr 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.5.1:
  * Bump github.com/containerd/containerd from 1.7.15 to 1.7.16
    (#148)
  * Bump github.com/onsi/gomega from 1.33.0 to 1.33.1 (#150)
  * Bump github.com/onsi/gomega from 1.32.0 to 1.33.0 (#143)
  * remove bundle injection, make golangci-lint config consistent
    (#145)
  * Bump github.com/operator-framework/operator-registry (#139)
  * update dependencies (#137)
  * update dependencies (#131)
  * GH Actions: add workflow to add epic issues to OLMv1 project
    (#121)
  * Remove timflannagan from OWNERS (#114)
  * Bump github.com/operator-framework/operator-registry (#104)
  * Bump github.com/opencontainers/image-spec from 1.1.0-rc4 to
    1.1.0-rc5 (#106)
  * Bump github.com/containerd/containerd from 1.7.6 to 1.7.12
    (#105)
  * manage tool deps with bingo (#102)
  * run CI in merge queue (#103)
  * deps: bump k8s.io to 0.28.5 and controller-runtime to 0.16.3
    (#101)
  * Bump actions/setup-go from 3 to 5 (#94)
  * Bump actions/checkout from 2 to 4 (#93)
  * deps: bump go version, operator-controller, and golangci-lint
    (#91)
  * enable dependabot (#92)
  * GH Actions CI and release improvements (#89)
* Fri Nov 17 2023 kastl@b1-systems.de
- Update to version 0.5.0:
  * list-operands: include namespace in error message when package
    is not found (#88)
  * Update to generic sets (#87)
  * OLMv1 Operator install/uninstall (#85)
  * Use package channel entries to lookup version (#76)
  * operator describe: don't panic when specified package name is
    not found (#79)
  * Fix install mode compatibility checking (#80)
  * Return only found PackageManifests (#78)
  * Bump to go 1.19 and k8s 1.25 (#77)
  * assets/demo: Use the eval built-in command for typed commands
    (#74)
  * .github: Fix the go-apidiff action and use the correct version
    (#75)
* Mon Oct 30 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kubectl-operator: Manage Kubernetes Operators from
  the command line
